The schematics inside the quaridne is like so --- we have a set of logical qubits which keep track of the states of the qubits.

NB!: 

The interesting addition for the MILP itself would be to add something like an einsum interface,
which will allow to describe the operations of the constraints in a simple manner, and in turn generate the constraints.
